==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridSortingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSortingStrategyDescription } from "./WebGridSortingStrategyDescription";
/**
 * @hidden
 */
var WebGridSortingStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridSortingStrategyDescriptionMetadata, _super);
    function WebGridSortingStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridSortingStrategyDescriptionMetadata.b = function (a) {
        if (WebGridSortingStrategyDescriptionMetadata.a == null) {
            WebGridSortingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridSortingStrategyDescriptionMetadata.c(WebGridSortingStrategyDescriptionMetadata.a);
        }
        if (a.j(WebGridSortingStrategyDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridSortingStrategyDescriptionMetadata.a);
    };
    WebGridSortingStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridSortingStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebGridSortingStrategyDescriptionMetadata.d = function (a) {
        WebGridSortingStrategyDescriptionMetadata.b(a);
        a.aa("WebGridSortingStrategy", function () { return new WebGridSortingStrategyDescription(); });
        a.z("WebGridSortingStrategy", WebGridSortingStrategyDescriptionMetadata.a);
    };
    WebGridSortingStrategyDescriptionMetadata.$t = markType(WebGridSortingStrategyDescriptionMetadata, 'WebGridSortingStrategyDescriptionMetadata');
    WebGridSortingStrategyDescriptionMetadata.a = null;
    return WebGridSortingStrategyDescriptionMetadata;
}(Base));
export { WebGridSortingStrategyDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridSortingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSortingStrategyDescription } from "./WebGridSortingStrategyDescription";
/**
 * @hidden
 */
var WebGridSortingStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridSortingStrategyDescriptionMetadata, _super);
    function WebGridSortingStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridSortingStrategyDescriptionMetadata.b = function (a) {
        if (WebGridSortingStrategyDescriptionMetadata.a == null) {
            WebGridSortingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridSortingStrategyDescriptionMetadata.c(WebGridSortingStrategyDescriptionMetadata.a);
        }
        if (a.k(WebGridSortingStrategyDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridSortingStrategyDescriptionMetadata.a);
    };
    WebGridSortingStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridSortingStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebGridSortingStrategyDescriptionMetadata.d = function (a) {
        WebGridSortingStrategyDescriptionMetadata.b(a);
        a.ac("WebGridSortingStrategy", function () { return new WebGridSortingStrategyDescription(); });
        a.ab("WebGridSortingStrategy", WebGridSortingStrategyDescriptionMetadata.a);
    };
    WebGridSortingStrategyDescriptionMetadata.$t = markType(WebGridSortingStrategyDescriptionMetadata, 'WebGridSortingStrategyDescriptionMetadata');
    WebGridSortingStrategyDescriptionMetadata.a = null;
    return WebGridSortingStrategyDescriptionMetadata;
}(Base));
export { WebGridSortingStrategyDescriptionMetadata };
